@@ -15,7 +15,7 @@ def sigmoid(logits):
         warnings.simplefilter("ignore")
         return 1 / (1 + np.exp(-1 * logits))
 
-def get_device(device):
+def get_device(device=None):
     if device == None:
         if torch.cuda.is_available():
             device = "cuda:0"
